@@ -49,7 +49,8 @@ if you don't export anything, such as for a purely object-oriented module.
 sub sum {
 
    my @inputlist = @_;
-   my $sum = 0;
+   #my $sum = 0;
+   my $sum = 1;
    OUTER:
    for my $each (@inputlist) {
        if ($each =~ /[A-Za-z]/){
@@ -57,7 +58,8 @@ sub sum {
           last OUTER;
           #die 'Only numbers allowed';
        };
-       $sum += $each;
+       #$sum += $each;
+       $sum = $sum * $each;
    }
    return $sum;
    
